@@ -4,9 +4,8 @@ import string
 import random
 
 from hashlib import md5
-from . import _pyco_json 
-from . import _pyco_json as _json
-from . import (
+from pyco_utils import (
+    _json,
     _coimp,
     _compat,
     _format,
@@ -17,7 +16,7 @@ from . import (
     const,
 )
 
-from ._coimp import (
+from pyco_utils._coimp import (
     print_log,
     reload_module,
     import_file,
@@ -25,8 +24,11 @@ from ._coimp import (
     clean_modules_from_dir,
 )
 
-__version__ = '0.1.9'
+__version__ = '0.2.0'
+__module_name = "pyco_utils"
 
+
+# from . import _json
 ## fixed: compat with _json.cpython on python>=3.7  
 sys.modules["pyco_utils._json"] = _json
 
